#include "main.h"

int main(void)
{
    RCC->APB2ENR |= RCC_APB2ENR_IOPCEN;

    GPIOC->CRH = (GPIOC->CRH
        & ~(0x0f << (4 * PIN_SUPPLY - 32)))
        | (0x01 << (4 * PIN_SUPPLY - 32))      // Output, max. 10 MHz
        ;

    GPIOC->BSRR = (1 << PIN_SUPPLY);

    Camera_Init();
    LTP1245_Init();

    LTP1245_FeedPaper(50);

    while(!Camera_Captured);

    extern uint8_t ImageBuffer[CAMERA_IMAGE_WIDTH * CAMERA_IMAGE_HEIGHT / 8];
    Print_Image(ImageBuffer, CAMERA_IMAGE_WIDTH, CAMERA_IMAGE_HEIGHT, 2);

#ifdef CONFIG_PRINT_EXPOSURE_DEBUG_INFORMATION
    char buffer[32] = "Finished after lines: ";
    itoa(Camera_FinalFrameCount, buffer + strlen(buffer), 10);

    Print_Text(buffer, &Hannover_Messe_Serif_26, Print_LeftAligned);
    Print_Text("Black pixel counts:", &Hannover_Messe_Serif_26,
        Print_LeftAligned);
    for(int i = 0; i < Camera_FinalFrameCount; i++)
    {
        if(i >= (int)(sizeof(Camera_BlackPixelCounts)
            / sizeof(Camera_BlackPixelCounts[0])))
        {
            break;
        }
        itoa(Camera_BlackPixelCounts[i], buffer, 10);
        Print_Text(buffer, &Hannover_Messe_Serif_26, Print_LeftAligned);
    }
#endif

    int file_number = BMP_Save(ImageBuffer, CAMERA_IMAGE_WIDTH,
        CAMERA_IMAGE_HEIGHT);
    (void)file_number;

#ifdef CONFIG_PRINT_FILE_NUMBER
    LTP1245_FeedPaper(10);
    char buffer[32] = "-   ";
    if(file_number >= 0)
    {
        itoa(file_number, buffer + strlen(buffer), 10);
        strcpy(buffer + strlen(buffer), "   -");
        Print_Text(buffer, &Hannover_Messe_Serif_26, Print_Centred);
    }
#endif
    
    LTP1245_FeedPaper(80);
    LTP1245_FeedPaper(10);

    GPIOC->BRR = (1 << PIN_SUPPLY);

    for(;;)
    {
        __WFI();
    }
}
